# -*- coding: utf-8 -*-
from collections import defaultdict

definitions = defaultdict(lambda: "Unknown", {
    'cam': 'a theater rip usually done with a digital video camera',
    'ts': 'A theater rip done with digital video camera with an external audio source',
    'tc': 'A telecine machine copies the film digitally from the reels',
    'dvdscr': ' transferred off a DVD sent to retail stores for promotional use',
    'retail': '',
    'hdtv': 'Digital recording from high definition source',
    'sdtv': '',
    'dvdr': '',
    'proper': '',
    'limited': '',
    'stv': '',
    'dc': 'Director\'s cut',
    'extended': '',
    'remastered': '',
    'unrated': '',
    'repack': '',
    'dubbed': '',
    'dvdrip': 'A copy of the final released DVD',
    'vhsrip': 'transferred off a retail VHS'
}
)
